# Security Policy

## Reporting a Vulnerability

The Oumi team and community take security bugs in Oumi seriously. We appreciate your efforts to responsibly disclose your findings, and will make every effort to acknowledge your contributions.

To report a security issue, please use the GitHub Security Advisory ["Report a Vulnerability"](https://github.com/oumi-ai/oumi/security/advisories/new) tab.

The Oumi team will send a response indicating the next steps in handling your report. After the initial reply to your report, the security team will keep you informed of the progress towards a fix and full announcement, and may ask for additional information or guidance.

Report security bugs in third-party modules to the person or team maintaining the module. You can also report a vulnerability through [PyPi](https://pypi.org/security/).

## Acknowledgements

We deeply appreciate security researchers who take the time to report vulnerabilities to us. We will acknowledge your contribution in our security advisory and release notes (unless you prefer to remain anonymous).

## Security Updates

Security updates and advisories will be published through GitHub Security Advisories.
